@@ -14,7 +14,7 @@
 # limitations under the License.
 #
 
-__version__ = "5.8.2"
+__version__ = "5.10.1"
 
 import argparse
 import configparser
@@ -26,7 +26,7 @@ import stat
 import sys
 from pathlib import Path
 
-from defusedxml import cElementTree as defused_et
+from defusedxml import ElementTree as defused_et
 from dunamai import Style, Version
 from jinja2 import Environment, FileSystemLoader
 
@@ -103,7 +103,7 @@ def recursive_overwrite(src, dest, ignore_list=None):
                     os.path.join(src, f), os.path.join(dest, f), ignore_list
                 )
             else:
-                logger.info("Excluding : {}".format(os.path.join(dest, f)))
+                logger.info(f"Excluding : {os.path.join(dest, f)}")
     else:
         if os.path.exists(dest):
             os.remove(dest)
@@ -316,7 +316,7 @@ def install_libs(path, ucc_lib_target):
             installer (str): Pip version(pip2/pip3).
         """
         if not os.path.exists(requirements):
-            logging.warning("Unable to find requirements file. {}".format(requirements))
+            logger.warning(f"Unable to find requirements file. {requirements}")
         else:
             if not os.path.exists(ucc_target):
                 os.makedirs(ucc_target)
@@ -331,9 +331,9 @@ def install_libs(path, ucc_lib_target):
             os.system(installer + " -m pip install pip --upgrade")
             os.system(install_cmd)
 
-    logging.info(f"  Checking for requirements in {path}")
+    logger.info(f"  Checking for requirements in {path}")
     if os.path.exists(os.path.join(path, "lib", "requirements.txt")):
-        logging.info("  Uses common requirements")
+        logger.info("  Uses common requirements")
         _install_libs(
             requirements=os.path.join(path, "lib", "requirements.txt"),
             ucc_target=ucc_lib_target,
@@ -341,7 +341,7 @@ def install_libs(path, ucc_lib_target):
     elif os.path.exists(
         os.path.join(os.path.abspath(os.path.join(path, os.pardir)), "requirements.txt")
     ):
-        logging.info("  Uses common requirements")
+        logger.info("  Uses common requirements")
         _install_libs(
             requirements=os.path.join(
                 os.path.abspath(os.path.join(path, os.pardir)), "requirements.txt"
@@ -349,7 +349,7 @@ def install_libs(path, ucc_lib_target):
             ucc_target=ucc_lib_target,
         )
     else:
-        logging.info("  Not using common requirements")
+        logger.info("  Not using common requirements")
 
     # Prevent certain packages from being included pip could be dangerous others are just wasted space
     noshipdirs = ["setuptools", "bin", "pip", "distribute", "wheel"]
@@ -684,6 +684,7 @@ def handle_no_inputs(ta_name, outputdir):
 
 
 def _generate(source, config, ta_version, outputdir=None):
+    logger.info(f"ucc-gen version {__version__} is used")
     if outputdir is None:
         outputdir = os.path.join(os.getcwd(), "output")
     if not ta_version:
@@ -701,7 +702,7 @@ def _generate(source, config, ta_version, outputdir=None):
         version_str = ta_version
 
     if not os.path.exists(source):
-        raise NotADirectoryError("{} not Found.".format(os.path.abspath(source)))
+        raise NotADirectoryError(f"{os.path.abspath(source)} not Found.")
 
     # Setting default value to Config argument
     if not config:
@@ -772,7 +773,7 @@ def _generate(source, config, ta_version, outputdir=None):
             ),
         )
         ucc_lib_target = os.path.join(outputdir, ta_name, "lib")
-        logger.info(f"Install Addon Requirements into {ucc_lib_target} from {source}")
+        logger.info(f"Install add-on requirements into {ucc_lib_target} from {source}")
         install_libs(source, ucc_lib_target)
 
         replace_token(ta_name, outputdir)
@@ -792,15 +793,11 @@ def _generate(source, config, ta_version, outputdir=None):
     else:
         logger.info("Addon Version : " + ta_version)
         logger.warning(
-            "Skipped installing UCC required python modules as GlobalConfig.json does not exist."
+            "Skipped generating UI components as globalConfig.json does not exist."
         )
-        logger.warning(
-            "Skipped Generating UI components as GlobalConfig.json does not exist."
-        )
-        logger.info("Setting TA name as generic")
-
         ucc_lib_target = os.path.join(outputdir, ta_name, "lib")
 
+        logger.info(f"Install add-on requirements into {ucc_lib_target} from {source}")
         install_libs(source, ucc_lib_target=ucc_lib_target)
 
     ignore_list = get_ignore_list(
