@@ -20,7 +20,7 @@ import os.path as op
 from os.path import basename as bn
 from shutil import copy
 
-from splunk_add_on_ucc_framework import conf_parser
+import addonfactory_splunk_conf_parser_lib as conf_parser
 
 from . import alert_actions_exceptions as aae
 from . import arf_consts as ac
@@ -136,4 +136,4 @@ def merge(src, dst, no_deny_list=True):
                 os.makedirs(op.join(dst, file))
             merge(f_path, op.join(dst, file))
         else:
-            raise Exception("Unsupported file type {}".format(f_path))
+            raise Exception(f"Unsupported file type {f_path}")
