@@ -25,20 +25,14 @@ import os.path as op
 import shutil
 
 from .endpoint.base import indent, quote_regex
-from .endpoint.datainput import (
-    DataInputEndpointBuilder,
-    DataInputEntityBuilder,
-)
+from .endpoint.datainput import DataInputEndpointBuilder, DataInputEntityBuilder
 from .endpoint.field import RestFieldBuilder
 from .endpoint.multiple_model import (
     MultipleModelEndpointBuilder,
     MultipleModelEntityBuilder,
 )
 from .endpoint.oauth_model import OAuthModelEndpointBuilder
-from .endpoint.single_model import (
-    SingleModelEndpointBuilder,
-    SingleModelEntityBuilder,
-)
+from .endpoint.single_model import SingleModelEndpointBuilder, SingleModelEntityBuilder
 
 
 def _is_true(val):
@@ -191,7 +185,7 @@ class GlobalConfigBuilderSchema:
                 namespace=self._meta["restRoot"],
                 j2_env=self.j2_env,
                 *args,
-                **kwargs
+                **kwargs,
             )
             self._endpoints[name] = endpoint
         return self._endpoints[name]
@@ -300,7 +294,7 @@ class GlobalConfigValidation:
             return ""
         args = list(
             map(
-                lambda k_v: "{}={}, ".format(k_v[0], k_v[1]),
+                lambda k_v: f"{k_v[0]}={k_v[1]}, ",
                 list(kwargs.items()),
             )
         )
@@ -435,7 +429,7 @@ sys.path = new_paths
     def import_declare_py_name(self):
         if self.import_declare_name:
             return self.import_declare_name
-        return "{}_import_declare".format(self.schema.namespace)
+        return f"{self.schema.namespace}_import_declare"
 
     def import_declare_py_content(self):
         import_declare_file = op.join(
